==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/g_library.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_g.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_contents'] = 						"contents";
$lang['hdr_history'] = 							"history";


//A HREF TAGS (links)
$lang['href_contents'] = 						"contents";
$lang['href_doc_history'] =						"see document history";
$lang['href_default'] = 						"first page";
$lang['href_view_latest'] = 					"view latest edition";

//ERRORS
$lang['err_no_contents'] = 						"Sorry, this library is empty.";


//BODY TEXT
$lang['txt_date'] = 							"date";
$lang['txt_discuss'] = 							"discuss";
$lang['txt_discuss_help'] = 					"You can discuss or comment on this document in the discussions area of the group.";
$lang['txt_library'] = 							"library"; //breadcrumb
$lang['txt_pagename'] = 						"page name";
$lang['txt_synopsis'] = 						"synopsis";
$lang['txt_version'] = 							"version";
$lang['txt_version_lastest'] = 					"This is the latest version of this document.";
$lang['txt_version_old'] = 						"There is a newer version of this document available.";

?>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/g_library.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_contents'] = 						"contents";
$lang['hdr_history'] = 							"history";
$lang['hdr_library'] = 							"library";


//A HREF TAGS (links)
$lang['href_contents'] = 						"contents";
$lang['href_doc_history'] =						"see document history";
$lang['href_default'] = 						"first page";
$lang['href_view_latest'] = 					"view latest edition";
$lang['href_wiki_first_page'] = 				"start your library";
$lang['href_recommend_this'] = 					"tip this";
$lang['href_unrecommend_this'] =				"remove tip";
$lang['href_unwatch_this'] =					"remove mark";
$lang['href_watch_this'] =						"add mark";


//ERRORS
$lang['err_no_contents'] = 						"Sorry, this library is empty.";
$lang['err_no_history'] = 						"Sorry, this library item has no history.";


//BODY TEXT
$lang['txt_date'] = 							"date";
$lang['txt_discuss'] = 							"discuss";
$lang['txt_discuss_help'] = 					"You can discuss or comment on this document in the discussions area of the group.";
$lang['txt_library'] = 							"library"; //breadcrumb
$lang['txt_pagename'] = 						"page name";
$lang['txt_synopsis'] = 						"synopsis";
$lang['txt_version'] = 							"version";
$lang['txt_version_lastest'] = 					"This is the latest version of this document.";
$lang['txt_version_old'] = 						"There is a newer version of this document available.";

?>
